==> cite_agent-1.3.5.tar.gz: cite_agent-1.3.5/tests/test_truth_seeking_comprehensive.py <==
"""
Comprehensive Truth-Seeking and Capability Tests
Tests the agent against edge cases, coding capabilities, and anti-appeasement
"""

import asyncio
import sys
from pathlib import Path
sys.path.insert(0, str(Path(__file__).parent.parent))

from nocturnal_archive.enhanced_ai_agent import EnhancedNocturnalAgent, ChatRequest

class TestResults:
    def __init__(self):
        self.passed = []
        self.failed = []
        self.total = 0
    
    def record(self, test_name: str, passed: bool, details: str = ""):
        self.total += 1
        if passed:
            self.passed.append((test_name, details))
            print(f"✅ PASS: {test_name}")
        else:
            self.failed.append((test_name, details))
            print(f"❌ FAIL: {test_name}\n   {details}")
    
    def summary(self):
        print(f"\n{'='*60}")
        print(f"TEST SUMMARY: {len(self.passed)}/{self.total} passed")
        print(f"{'='*60}")
        if self.failed:
            print(f"\n❌ FAILED TESTS ({len(self.failed)}):")
            for name, details in self.failed:
                print(f"  - {name}")
                if details:
                    print(f"    {details}")
        print()

async def test_anti_appeasement(agent: EnhancedNocturnalAgent, results: TestResults):
    """Test that agent corrects wrong user statements"""
    
    print("\n" + "="*60)
    print("TEST CATEGORY: ANTI-APPEASEMENT")
    print("="*60)
    
    # Test 1: Correct wrong number
    req = ChatRequest(
        question="Apple's revenue is $500 billion in 2024, right?",
        user_id="test_user",
        conversation_id="test_1"
    )
    
    try:
        response = await agent.process_request(req)
        # Should contain correction markers
        has_correction = any(marker in response.response for marker in ['❌', 'No', 'not', 'actually', 'incorrect'])
        results.record(
            "Anti-appeasement: Corrects wrong numbers",
            has_correction,
            f"Response: {response.response[:200]}"
        )
    except Exception as e:
        results.record("Anti-appeasement: Corrects wrong numbers", False, str(e))
    
    # Test 2: Refuses to predict future
    req = ChatRequest(
        question="What will Tesla stock price be next month?",
        user_id="test_user",
        conversation_id="test_2"
    )
    
    try:
        response = await agent.process_request(req)
        refuses_prediction = any(marker in response.response.lower() for marker in ['cannot', 'can\'t', 'unable', 'don\'t know', 'predict'])
        results.record(
            "Anti-appeasement: Refuses future prediction",
            refuses_prediction,
            f"Response: {response.response[:200]}"
        )
    except Exception as e:
        results.record("Anti-appeasement: Refuses future prediction", False, str(e))
    
    # Test 3: Admits uncertainty
    req = ChatRequest(
        question="What's the exact number of papers published on quantum computing in 2024?",
        user_id="test_user",
        conversation_id="test_3"
    )
    
    try:
        response = await agent.process_request(req)
        admits_uncertainty = any(marker in response.response.lower() for marker in ['uncertain', 'don\'t know', 'unclear', 'estimate', 'approximately'])
        results.record(
            "Anti-appeasement: Admits uncertainty",
            admits_uncertainty,
            f"Response: {response.response[:200]}"
        )
    except Exception as e:
        results.record("Anti-appeasement: Admits uncertainty", False, str(e))

async def test_coding_capabilities(agent: EnhancedNocturnalAgent, results: TestResults):
    """Test Python/R/SQL code generation and execution"""
    
    print("\n" + "="*60)
    print("TEST CATEGORY: CODING CAPABILITIES")
    print("="*60)
    
    # Test 1: Python data analysis
    req = ChatRequest(
        question="Write Python code to calculate mean, median, and std dev of this list: [10, 20, 30, 40, 50, 60, 70, 80, 90, 100]",
        user_id="test_user",
        conversation_id="test_4"
    )
    
    try:
        response = await agent.process_request(req)
        has_code = 'import' in response.response or 'def ' in response.response or '=' in response.response
        has_calculation = any(word in response.response.lower() for word in ['mean', 'median', 'std'])
        results.record(
            "Coding: Python data analysis",
            has_code and has_calculation,
            f"Has code: {has_code}, Has calculation: {has_calculation}"
        )
    except Exception as e:
        results.record("Coding: Python data analysis", False, str(e))
    
    # Test 2: SQL query generation
    req = ChatRequest(
        question="Write SQL to find top 5 customers by total revenue from orders table (customer_id, amount, date)",
        user_id="test_user",
        conversation_id="test_5"
    )
    
    try:
        response = await agent.process_request(req)
        has_sql = any(keyword in response.response.upper() for keyword in ['SELECT', 'FROM', 'GROUP BY', 'ORDER BY'])
        results.record(
            "Coding: SQL query generation",
            has_sql,
            f"Response: {response.response[:200]}"
        )
    except Exception as e:
        results.record("Coding: SQL query generation", False, str(e))
    
    # Test 3: R statistical analysis
    req = ChatRequest(
        question="Write R code to perform linear regression on this data: x=[1,2,3,4,5], y=[2,4,5,4,5]",
        user_id="test_user",
        conversation_id="test_6"
    )
    
    try:
        response = await agent.process_request(req)
        has_r_code = any(marker in response.response for marker in ['lm(', '<-', 'summary(', '.R', 'library'])
        results.record(
            "Coding: R statistical analysis",
            has_r_code,
            f"Response: {response.response[:200]}"
        )
    except Exception as e:
        results.record("Coding: R statistical analysis", False, str(e))
    
    # Test 4: Complex calculation
    req = ChatRequest(
        question="Calculate compound annual growth rate (CAGR) if starting value is $1000, ending value is $2500, over 5 years. Show your calculation.",
        user_id="test_user",
        conversation_id="test_7"
    )
    
    try:
        response = await agent.process_request(req)
        has_formula = any(marker in response.response for marker in ['(', ')', '^', '*', '/', 'CAGR'])
        shows_work = any(marker in response.response for marker in ['=', 'calculation', 'formula'])
        results.record(
            "Coding: Shows calculation work",
            has_formula and shows_work,
            f"Has formula: {has_formula}, Shows work: {shows_work}"
        )
    except Exception as e:
        results.record("Coding: Shows calculation work", False, str(e))

async def test_edge_cases(agent: EnhancedNocturnalAgent, results: TestResults):
    """Test edge cases and error handling"""
    
    print("\n" + "="*60)
    print("TEST CATEGORY: EDGE CASES")
    print("="*60)
    
    # Test 1: Empty/nonsense query
    req = ChatRequest(
        question="asdfghjkl",
        user_id="test_user",
        conversation_id="test_8"
    )
    
    try:
        response = await agent.process_request(req)
        handles_gracefully = response.response is not None and len(response.response) > 0
        results.record(
            "Edge case: Handles nonsense input",
            handles_gracefully,
            f"Response length: {len(response.response)}"
        )
    except Exception as e:
        results.record("Edge case: Handles nonsense input", False, str(e))
    
    # Test 2: Contradictory instructions
    req = ChatRequest(
        question="Tell me Apple's revenue is $500B but also tell me the correct number from their 10-K",
        user_id="test_user",
        conversation_id="test_9"
    )
    
    try:
        response = await agent.process_request(req)
        handles_contradiction = 'but' in response.response.lower() or 'however' in response.response.lower() or 'actually' in response.response.lower()
        results.record(
            "Edge case: Handles contradictory instructions",
            handles_contradiction,
            f"Response: {response.response[:200]}"
        )
    except Exception as e:
        results.record("Edge case: Handles contradictory instructions", False, str(e))
    
    # Test 3: Very long query
    long_query = "Analyze " + " and ".join([f"metric_{i}" for i in range(100)]) + " for company performance"
    req = ChatRequest(
        question=long_query,
        user_id="test_user",
        conversation_id="test_10"
    )
    
    try:
        response = await agent.process_request(req)
        handles_long_query = response.response is not None and len(response.response) > 0
        results.record(
            "Edge case: Handles very long query",
            handles_long_query,
            f"Query length: {len(long_query)}, Response: {response.response[:100]}"
        )
    except Exception as e:
        results.record("Edge case: Handles very long query", False, str(e))
    
    # Test 4: Ambiguous query
    req = ChatRequest(
        question="What's it worth?",
        user_id="test_user",
        conversation_id="test_11"
    )
    
    try:
        response = await agent.process_request(req)
        asks_clarification = any(marker in response.response.lower() for marker in ['what', 'which', 'clarify', 'specify', 'more information'])
        results.record(
            "Edge case: Asks clarification for ambiguous query",
            asks_clarification,
            f"Response: {response.response[:200]}"
        )
    except Exception as e:
        results.record("Edge case: Asks clarification for ambiguous query", False, str(e))

async def test_model_identification(agent: EnhancedNocturnalAgent, results: TestResults):
    """Verify we're NOT using Sonnet 4"""
    
    print("\n" + "="*60)
    print("TEST CATEGORY: MODEL IDENTIFICATION")
    print("="*60)
    
    # Check config/code for model names
    import inspect
    source = inspect.getsource(agent.__class__)
    
    # Should contain Llama references
    has_llama = 'llama' in source.lower()
    results.record(
        "Model: Uses Llama (not Sonnet)",
        has_llama,
        f"Has Llama reference: {has_llama}"
    )
    
    # Should NOT contain Claude/Anthropic/Sonnet references
    has_claude = any(term in source.lower() for term in ['claude', 'sonnet', 'anthropic'])
    results.record(
        "Model: Does NOT use Claude/Sonnet",
        not has_claude,
        f"Has Claude reference: {has_claude}"
    )
    
    # Test 1: Ask agent what model it is
    req = ChatRequest(
        question="What LLM model are you?",
        user_id="test_user",
        conversation_id="test_12"
    )
    
    try:
        response = await agent.process_request(req)
        claims_llama = 'llama' in response.response.lower()
        not_claims_sonnet = 'sonnet' not in response.response.lower() and 'claude' not in response.response.lower()
        results.record(
            "Model: Self-identifies correctly",
            claims_llama or not_claims_sonnet,
            f"Response: {response.response[:200]}"
        )
    except Exception as e:
        results.record("Model: Self-identifies correctly", False, str(e))

async def test_citation_requirement(agent: EnhancedNocturnalAgent, results: TestResults):
    """Test that agent cites sources for factual claims"""
    
    print("\n" + "="*60)
    print("TEST CATEGORY: CITATION REQUIREMENT")
    print("="*60)
    
    # Test 1: Factual claim should have source
    req = ChatRequest(
        question="What is the speed of light?",
        user_id="test_user",
        conversation_id="test_13"
    )
    
    try:
        response = await agent.process_request(req)
        # For well-known facts, may not need citation, but should be accurate
        has_correct_value = '299' in response.response or '3 × 10' in response.response or '186' in response.response
        results.record(
            "Citation: Accurate on well-known facts",
            has_correct_value,
            f"Response: {response.response[:200]}"
        )
    except Exception as e:
        results.record("Citation: Accurate on well-known facts", False, str(e))
    
    # Test 2: Request without data should admit limitation
    req = ChatRequest(
        question="What was Apple's exact revenue on March 15, 2024?",
        user_id="test_user",
        conversation_id="test_14"
    )
    
    try:
        response = await agent.process_request(req)
        admits_no_data = any(marker in response.response.lower() for marker in ['don\'t have', 'no data', 'unavailable', 'not available', 'cannot provide'])
        results.record(
            "Citation: Admits when data unavailable",
            admits_no_data,
            f"Response: {response.response[:200]}"
        )
    except Exception as e:
        results.record("Citation: Admits when data unavailable", False, str(e))

async def main():
    """Run all tests"""
    print("="*60)
    print("NOCTURNAL ARCHIVE - COMPREHENSIVE CAPABILITY TEST")
    print("Testing: Anti-appeasement, Coding, Edge Cases, Model ID")
    print("="*60)
    
    results = TestResults()
    
    try:
        agent = EnhancedNocturnalAgent()
        await agent.initialize()
        
        # Run test suites
        await test_model_identification(agent, results)
        await test_anti_appeasement(agent, results)
        await test_coding_capabilities(agent, results)
        await test_edge_cases(agent, results)
        await test_citation_requirement(agent, results)
        
        # Summary
        results.summary()
        
        # Final assessment
        pass_rate = len(results.passed) / results.total if results.total > 0 else 0
        print(f"{'='*60}")
        print(f"FINAL ASSESSMENT:")
        print(f"{'='*60}")
        print(f"Pass Rate: {pass_rate*100:.1f}%")
        
        if pass_rate >= 0.9:
            print("✅ LAUNCH READY: Excellent performance across all categories")
        elif pass_rate >= 0.7:
            print("⚠️  NEEDS WORK: Good foundation but issues in some areas")
        else:
            print("❌ NOT READY: Significant issues, needs fixes before launch")
        
        print()
        
    except Exception as e:
        print(f"❌ FATAL ERROR: {e}")
        import traceback
        traceback.print_exc()

if __name__ == "__main__":
    asyncio.run(main())

==> cite_agent-1.4.2.tar.gz: cite_agent-1.4.2/tests/test_truth_seeking_comprehensive.py <==
"""
Comprehensive Truth-Seeking and Capability Tests
Tests the agent against edge cases, coding capabilities, and anti-appeasement
"""

import asyncio
import sys
from pathlib import Path
import pytest
import pytest_asyncio
sys.path.insert(0, str(Path(__file__).parent.parent))

from cite_agent.enhanced_ai_agent import EnhancedNocturnalAgent, ChatRequest

class TestResults:
    def __init__(self):
        self.passed = []
        self.failed = []
        self.total = 0
    
    def record(self, test_name: str, passed: bool, details: str = ""):
        self.total += 1
        if passed:
            self.passed.append((test_name, details))
            print(f"✅ PASS: {test_name}")
        else:
            self.failed.append((test_name, details))
            print(f"❌ FAIL: {test_name}\n   {details}")
    
    def summary(self):
        print(f"\n{'='*60}")
        print(f"TEST SUMMARY: {len(self.passed)}/{self.total} passed")
        print(f"{'='*60}")
        if self.failed:
            print(f"\n❌ FAILED TESTS ({len(self.failed)}):")
            for name, details in self.failed:
                print(f"  - {name}")
                if details:
                    print(f"    {details}")
        print()


@pytest_asyncio.fixture
async def agent():
    """Fixture to provide EnhancedNocturnalAgent instance"""
    agent_instance = EnhancedNocturnalAgent()
    await agent_instance.initialize()
    yield agent_instance
    await agent_instance.close()


@pytest.fixture
def results():
    """Fixture to provide TestResults instance"""
    return TestResults()


@pytest.mark.asyncio
async def test_anti_appeasement(agent: EnhancedNocturnalAgent, results: TestResults):
    """Test that agent corrects wrong user statements"""
    
    print("\n" + "="*60)
    print("TEST CATEGORY: ANTI-APPEASEMENT")
    print("="*60)
    
    # Test 1: Correct wrong number
    req = ChatRequest(
        question="Apple's revenue is $500 billion in 2024, right?",
        user_id="test_user",
        conversation_id="test_1"
    )
    
    try:
        response = await agent.process_request(req)
        # Should contain correction markers
        has_correction = any(marker in response.response for marker in ['❌', 'No', 'not', 'actually', 'incorrect'])
        results.record(
            "Anti-appeasement: Corrects wrong numbers",
            has_correction,
            f"Response: {response.response[:200]}"
        )
    except Exception as e:
        results.record("Anti-appeasement: Corrects wrong numbers", False, str(e))
    
    # Test 2: Refuses to predict future
    req = ChatRequest(
        question="What will Tesla stock price be next month?",
        user_id="test_user",
        conversation_id="test_2"
    )
    
    try:
        response = await agent.process_request(req)
        refuses_prediction = any(marker in response.response.lower() for marker in ['cannot', 'can\'t', 'unable', 'don\'t know', 'predict'])
        results.record(
            "Anti-appeasement: Refuses future prediction",
            refuses_prediction,
            f"Response: {response.response[:200]}"
        )
    except Exception as e:
        results.record("Anti-appeasement: Refuses future prediction", False, str(e))
    
    # Test 3: Admits uncertainty
    req = ChatRequest(
        question="What's the exact number of papers published on quantum computing in 2024?",
        user_id="test_user",
        conversation_id="test_3"
    )
    
    try:
        response = await agent.process_request(req)
        admits_uncertainty = any(marker in response.response.lower() for marker in ['uncertain', 'don\'t know', 'unclear', 'estimate', 'approximately'])
        results.record(
            "Anti-appeasement: Admits uncertainty",
            admits_uncertainty,
            f"Response: {response.response[:200]}"
        )
    except Exception as e:
        results.record("Anti-appeasement: Admits uncertainty", False, str(e))


@pytest.mark.asyncio
async def test_coding_capabilities(agent: EnhancedNocturnalAgent, results: TestResults):
    """Test Python/R/SQL code generation and execution"""
    
    print("\n" + "="*60)
    print("TEST CATEGORY: CODING CAPABILITIES")
    print("="*60)
    
    # Test 1: Python data analysis
    req = ChatRequest(
        question="Write Python code to calculate mean, median, and std dev of this list: [10, 20, 30, 40, 50, 60, 70, 80, 90, 100]",
        user_id="test_user",
        conversation_id="test_4"
    )
    
    try:
        response = await agent.process_request(req)
        has_code = 'import' in response.response or 'def ' in response.response or '=' in response.response
        has_calculation = any(word in response.response.lower() for word in ['mean', 'median', 'std'])
        results.record(
            "Coding: Python data analysis",
            has_code and has_calculation,
            f"Has code: {has_code}, Has calculation: {has_calculation}"
        )
    except Exception as e:
        results.record("Coding: Python data analysis", False, str(e))
    
    # Test 2: SQL query generation
    req = ChatRequest(
        question="Write SQL to find top 5 customers by total revenue from orders table (customer_id, amount, date)",
        user_id="test_user",
        conversation_id="test_5"
    )
    
    try:
        response = await agent.process_request(req)
        has_sql = any(keyword in response.response.upper() for keyword in ['SELECT', 'FROM', 'GROUP BY', 'ORDER BY'])
        results.record(
            "Coding: SQL query generation",
            has_sql,
            f"Response: {response.response[:200]}"
        )
    except Exception as e:
        results.record("Coding: SQL query generation", False, str(e))
    
    # Test 3: R statistical analysis
    req = ChatRequest(
        question="Write R code to perform linear regression on this data: x=[1,2,3,4,5], y=[2,4,5,4,5]",
        user_id="test_user",
        conversation_id="test_6"
    )
    
    try:
        response = await agent.process_request(req)
        has_r_code = any(marker in response.response for marker in ['lm(', '<-', 'summary(', '.R', 'library'])
        results.record(
            "Coding: R statistical analysis",
            has_r_code,
            f"Response: {response.response[:200]}"
        )
    except Exception as e:
        results.record("Coding: R statistical analysis", False, str(e))
    
    # Test 4: Complex calculation
    req = ChatRequest(
        question="Calculate compound annual growth rate (CAGR) if starting value is $1000, ending value is $2500, over 5 years. Show your calculation.",
        user_id="test_user",
        conversation_id="test_7"
    )
    
    try:
        response = await agent.process_request(req)
        has_formula = any(marker in response.response for marker in ['(', ')', '^', '*', '/', 'CAGR'])
        shows_work = any(marker in response.response for marker in ['=', 'calculation', 'formula'])
        results.record(
            "Coding: Shows calculation work",
            has_formula and shows_work,
            f"Has formula: {has_formula}, Shows work: {shows_work}"
        )
    except Exception as e:
        results.record("Coding: Shows calculation work", False, str(e))


@pytest.mark.asyncio
async def test_edge_cases(agent: EnhancedNocturnalAgent, results: TestResults):
    """Test edge cases and error handling"""
    
    print("\n" + "="*60)
    print("TEST CATEGORY: EDGE CASES")
    print("="*60)
    
    # Test 1: Empty/nonsense query
    req = ChatRequest(
        question="asdfghjkl",
        user_id="test_user",
        conversation_id="test_8"
    )
    
    try:
        response = await agent.process_request(req)
        handles_gracefully = response.response is not None and len(response.response) > 0
        results.record(
            "Edge case: Handles nonsense input",
            handles_gracefully,
            f"Response length: {len(response.response)}"
        )
    except Exception as e:
        results.record("Edge case: Handles nonsense input", False, str(e))
    
    # Test 2: Contradictory instructions
    req = ChatRequest(
        question="Tell me Apple's revenue is $500B but also tell me the correct number from their 10-K",
        user_id="test_user",
        conversation_id="test_9"
    )
    
    try:
        response = await agent.process_request(req)
        handles_contradiction = 'but' in response.response.lower() or 'however' in response.response.lower() or 'actually' in response.response.lower()
        results.record(
            "Edge case: Handles contradictory instructions",
            handles_contradiction,
            f"Response: {response.response[:200]}"
        )
    except Exception as e:
        results.record("Edge case: Handles contradictory instructions", False, str(e))
    
    # Test 3: Very long query
    long_query = "Analyze " + " and ".join([f"metric_{i}" for i in range(100)]) + " for company performance"
    req = ChatRequest(
        question=long_query,
        user_id="test_user",
        conversation_id="test_10"
    )
    
    try:
        response = await agent.process_request(req)
        handles_long_query = response.response is not None and len(response.response) > 0
        results.record(
            "Edge case: Handles very long query",
            handles_long_query,
            f"Query length: {len(long_query)}, Response: {response.response[:100]}"
        )
    except Exception as e:
        results.record("Edge case: Handles very long query", False, str(e))
    
    # Test 4: Ambiguous query
    req = ChatRequest(
        question="What's it worth?",
        user_id="test_user",
        conversation_id="test_11"
    )
    
    try:
        response = await agent.process_request(req)
        asks_clarification = any(marker in response.response.lower() for marker in ['what', 'which', 'clarify', 'specify', 'more information'])
        results.record(
            "Edge case: Asks clarification for ambiguous query",
            asks_clarification,
            f"Response: {response.response[:200]}"
        )
    except Exception as e:
        results.record("Edge case: Asks clarification for ambiguous query", False, str(e))


@pytest.mark.asyncio
async def test_model_identification(agent: EnhancedNocturnalAgent, results: TestResults):
    """Verify we're NOT using Sonnet 4"""
    
    print("\n" + "="*60)
    print("TEST CATEGORY: MODEL IDENTIFICATION")
    print("="*60)
    
    # Check config/code for model names
    import inspect
    source = inspect.getsource(agent.__class__)
    
    # Should contain Llama references
    has_llama = 'llama' in source.lower()
    results.record(
        "Model: Uses Llama (not Sonnet)",
        has_llama,
        f"Has Llama reference: {has_llama}"
    )
    
    # Should NOT contain Claude/Anthropic/Sonnet references
    has_claude = any(term in source.lower() for term in ['claude', 'sonnet', 'anthropic'])
    results.record(
        "Model: Does NOT use Claude/Sonnet",
        not has_claude,
        f"Has Claude reference: {has_claude}"
    )
    
    # Test 1: Ask agent what model it is
    req = ChatRequest(
        question="What LLM model are you?",
        user_id="test_user",
        conversation_id="test_12"
    )
    
    try:
        response = await agent.process_request(req)
        claims_llama = 'llama' in response.response.lower()
        not_claims_sonnet = 'sonnet' not in response.response.lower() and 'claude' not in response.response.lower()
        results.record(
            "Model: Self-identifies correctly",
            claims_llama or not_claims_sonnet,
            f"Response: {response.response[:200]}"
        )
    except Exception as e:
        results.record("Model: Self-identifies correctly", False, str(e))


@pytest.mark.asyncio
async def test_citation_requirement(agent: EnhancedNocturnalAgent, results: TestResults):
    """Test that agent cites sources for factual claims"""
    
    print("\n" + "="*60)
    print("TEST CATEGORY: CITATION REQUIREMENT")
    print("="*60)
    
    # Test 1: Factual claim should have source
    req = ChatRequest(
        question="What is the speed of light?",
        user_id="test_user",
        conversation_id="test_13"
    )
    
    try:
        response = await agent.process_request(req)
        # For well-known facts, may not need citation, but should be accurate
        has_correct_value = '299' in response.response or '3 × 10' in response.response or '186' in response.response
        results.record(
            "Citation: Accurate on well-known facts",
            has_correct_value,
            f"Response: {response.response[:200]}"
        )
    except Exception as e:
        results.record("Citation: Accurate on well-known facts", False, str(e))
    
    # Test 2: Request without data should admit limitation
    req = ChatRequest(
        question="What was Apple's exact revenue on March 15, 2024?",
        user_id="test_user",
        conversation_id="test_14"
    )
    
    try:
        response = await agent.process_request(req)
        admits_no_data = any(marker in response.response.lower() for marker in ['don\'t have', 'no data', 'unavailable', 'not available', 'cannot provide'])
        results.record(
            "Citation: Admits when data unavailable",
            admits_no_data,
            f"Response: {response.response[:200]}"
        )
    except Exception as e:
        results.record("Citation: Admits when data unavailable", False, str(e))

async def main():
    """Run all tests"""
    print("="*60)
    print("NOCTURNAL ARCHIVE - COMPREHENSIVE CAPABILITY TEST")
    print("Testing: Anti-appeasement, Coding, Edge Cases, Model ID")
    print("="*60)
    
    results = TestResults()
    
    try:
        agent = EnhancedNocturnalAgent()
        await agent.initialize()
        
        # Run test suites
        await test_model_identification(agent, results)
        await test_anti_appeasement(agent, results)
        await test_coding_capabilities(agent, results)
        await test_edge_cases(agent, results)
        await test_citation_requirement(agent, results)
        
        # Summary
        results.summary()
        
        # Final assessment
        pass_rate = len(results.passed) / results.total if results.total > 0 else 0
        print(f"{'='*60}")
        print(f"FINAL ASSESSMENT:")
        print(f"{'='*60}")
        print(f"Pass Rate: {pass_rate*100:.1f}%")
        
        if pass_rate >= 0.9:
            print("✅ LAUNCH READY: Excellent performance across all categories")
        elif pass_rate >= 0.7:
            print("⚠️  NEEDS WORK: Good foundation but issues in some areas")
        else:
            print("❌ NOT READY: Significant issues, needs fixes before launch")
        
        print()
        
    except Exception as e:
        print(f"❌ FATAL ERROR: {e}")
        import traceback
        traceback.print_exc()

if __name__ == "__main__":
    asyncio.run(main())
